registerKey constant

Spec<RegisterKeyRequest, RegisterKeyResponse> const registerKey

RegisterKey registers a key with a third-party service using an externally-generated key or token. This method handles the integration with the external service and stores metadata about the key, but not the key material itself. Use AddKey to store key material.

Implementation

static const registerKey = connect.Spec(
  '/$name/RegisterKey',
  connect.StreamType.unary,
  devicev1device.RegisterKeyRequest.new,
  devicev1device.RegisterKeyResponse.new,
);