registerKey method

Future<RegisterKeyResponse> registerKey(
  1. RegisterKeyRequest input, {
  2. Headers? headers,
  3. AbortSignal? signal,
  4. dynamic onHeader(
    1. Headers
    )?,
  5. dynamic onTrailer(
    1. Headers
    )?,
})

RegisterKey registers a key with a third-party service using an externally-generated key or token. This method handles the integration with the external service and stores metadata about the key, but not the key material itself. Use AddKey to store key material.

Implementation

Future<devicev1device.RegisterKeyResponse> registerKey(
  devicev1device.RegisterKeyRequest input, {
  connect.Headers? headers,
  connect.AbortSignal? signal,
  Function(connect.Headers)? onHeader,
  Function(connect.Headers)? onTrailer,
}) {
  return connect.Client(_transport).unary(
    specs.DeviceService.registerKey,
    input,
    signal: signal,
    headers: headers,
    onHeader: onHeader,
    onTrailer: onTrailer,
  );
}