keyId property

  1. @TagNumber.new(2)
String get keyId

The following fields remain for backward compatibility and represent a single notification payload. New integrations should prefer the notifications field for bulk sending.

Implementation

@$pb.TagNumber(2)
$core.String get keyId => $_getSZ(1);
  1. @TagNumber.new(2)
set keyId (String v)

Implementation

@$pb.TagNumber(2)
set keyId($core.String v) { $_setString(1, v); }