PresenceStatus class
PresenceStatus defines the online/offline status of a device. buf:lint:ignore ENUM_VALUE_PREFIX
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → PresenceStatus?
Constants
- AWAY → const PresenceStatus
- BUSY → const PresenceStatus
- INVISIBLE → const PresenceStatus
- OFFLINE → const PresenceStatus
- ONLINE → const PresenceStatus
-
values
→ const List<
PresenceStatus>