SettingsServiceApi class
Constructors
- SettingsServiceApi(RpcClient _client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
ClientContext? ctx, GetRequest request) → Future< GetResponse> -
list(
ClientContext? ctx, ListRequest request) → Future< ListResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
search(
ClientContext? ctx, SearchRequest request) → Future< SearchResponse> -
set(
ClientContext? ctx, SetRequest request) → Future< SetResponse> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited