addKey constant
Spec<AddKeyRequest, AddKeyResponse>
const addKey
AddKey stores a key or token and its material in the local storage for a device. This is used for keys generated by the service or when the service needs to manage the key material directly.
Implementation
static const addKey = connect.Spec(
'/$name/AddKey',
connect.StreamType.unary,
devicev1device.AddKeyRequest.new,
devicev1device.AddKeyResponse.new,
);