notify constant
Spec<NotifyRequest, NotifyResponse>
const notify
Notify sends a notification to a device using one of its registered keys. The service selects an appropriate key based on key_type (e.g., FCM_TOKEN for push notifications). If key_id is provided, that specific key will be used; otherwise the service selects the best available key.
Implementation
static const notify = connect.Spec(
'/$name/Notify',
connect.StreamType.unary,
devicev1device.NotifyRequest.new,
devicev1device.NotifyResponse.new,
);