notify method
Future<NotifyResponse>
notify(
- NotifyRequest input, {
- Headers? headers,
- AbortSignal? signal,
- dynamic onHeader(
- Headers
- dynamic onTrailer(
- Headers
Notify sends a notification to a device using one of its registered keys. The service selects an appropriate key based on key_type (e.g., FCM_TOKEN for push notifications). If key_id is provided, that specific key will be used; otherwise the service selects the best available key.
Implementation
Future<devicev1device.NotifyResponse> notify(
devicev1device.NotifyRequest input, {
connect.Headers? headers,
connect.AbortSignal? signal,
Function(connect.Headers)? onHeader,
Function(connect.Headers)? onTrailer,
}) {
return connect.Client(_transport).unary(
specs.DeviceService.notify,
input,
signal: signal,
headers: headers,
onHeader: onHeader,
onTrailer: onTrailer,
);
}