registerKey method
Future<RegisterKeyResponse>
registerKey(
- RegisterKeyRequest input, {
- Headers? headers,
- AbortSignal? signal,
- dynamic onHeader(
- Headers
- dynamic onTrailer(
- Headers
RegisterKey registers a key with a third-party service using an externally-generated key or token. This method handles the integration with the external service and stores metadata about the key, but not the key material itself. Use AddKey to store key material.
Implementation
Future<devicev1device.RegisterKeyResponse> registerKey(
devicev1device.RegisterKeyRequest input, {
connect.Headers? headers,
connect.AbortSignal? signal,
Function(connect.Headers)? onHeader,
Function(connect.Headers)? onTrailer,
}) {
return connect.Client(_transport).unary(
specs.DeviceService.registerKey,
input,
signal: signal,
headers: headers,
onHeader: onHeader,
onTrailer: onTrailer,
);
}