get constant
Spec<GetRequest, GetResponse>
const get
Get retrieves a single setting value by its hierarchical key. Returns the most specific matching setting based on the key hierarchy.
Implementation
static const get = connect.Spec(
'/$name/Get',
connect.StreamType.unary,
settingsv1settings.GetRequest.new,
settingsv1settings.GetResponse.new,
idempotency: connect.Idempotency.noSideEffects,
);